@@ -50,29 +50,12 @@ static gboolean _roll_end (GESTimelineElement * element, GstClockTime end);
 static gboolean _trim (GESTimelineElement * element, GstClockTime start);
 static void _compute_height (GESContainer * container);
 
-typedef enum
-{
-  GES_CLIP_IS_SPLITTING = (1 << 0),
-  GES_CLIP_IS_MOVING = (1 << 1),
-} GESClipFlags;
-
-#define FLAGS(obj)             (GES_CLIP(obj)->priv->flags)
-#define SET_FLAG(obj,flag)     (FLAGS(obj) |= (flag))
-#define UNSET_FLAG(obj,flag)   (FLAGS(obj) &= ~(flag))
-#define FLAG_IS_SET(obj,flag)  (FLAGS(obj) == (flag))
-
 struct _GESClipPrivate
 {
   /*< public > */
   GESLayer *layer;
 
   /*< private > */
-
-  /* Set to TRUE when the clip is doing updates of track element
-   * properties so we don't end up in infinite property update loops
-   */
-  GESClipFlags flags;
-
   guint nb_effects;
 
   GList *copied_track_elements;
@@ -151,7 +134,6 @@ static gboolean
 _set_start (GESTimelineElement * element, GstClockTime start)
 {
   GList *tmp;
-  GESTimeline *timeline;
   GESContainer *container = GES_CONTAINER (element);
 
   GST_DEBUG_OBJECT (element, "Setting children start, (initiated_move: %"
@@ -163,17 +145,7 @@ _set_start (GESTimelineElement * element, GstClockTime start)
   for (tmp = container->children; tmp; tmp = g_list_next (tmp)) {
     GESTimelineElement *child = (GESTimelineElement *) tmp->data;
 
-    if (child != container->initiated_move) {
-      /* Make the snapping happen if in a timeline */
-      timeline = GES_TIMELINE_ELEMENT_TIMELINE (child);
-      if (timeline && !container->initiated_move) {
-        if (ges_timeline_move_object_simple (timeline, child, NULL,
-                GES_EDGE_NONE, start))
-          continue;
-      }
-
-      _set_start0 (GES_TIMELINE_ELEMENT (child), start);
-    }
+    _set_start0 (GES_TIMELINE_ELEMENT (child), start);
   }
   container->children_control_mode = GES_CHILDREN_UPDATE;
 
@@ -203,7 +175,6 @@ static gboolean
 _set_duration (GESTimelineElement * element, GstClockTime duration)
 {
   GList *tmp;
-  GESTimeline *timeline;
 
   GESContainer *container = GES_CONTAINER (element);
 
@@ -211,16 +182,8 @@ _set_duration (GESTimelineElement * element, GstClockTime duration)
   for (tmp = container->children; tmp; tmp = g_list_next (tmp)) {
     GESTimelineElement *child = (GESTimelineElement *) tmp->data;
 
-    if (child != container->initiated_move) {
-      /* Make the snapping happen if in a timeline */
-      timeline = GES_TIMELINE_ELEMENT_TIMELINE (child);
-      if (timeline == NULL || FLAG_IS_SET (element, GES_CLIP_IS_SPLITTING) ||
-          (ges_timeline_trim_object_simple (timeline, child,
-                  NULL, GES_EDGE_END, _START (child) + duration,
-                  TRUE) == FALSE)) {
-        _set_duration0 (GES_TIMELINE_ELEMENT (child), duration);
-      }
-    }
+    if (child != container->initiated_move)
+      _set_duration0 (GES_TIMELINE_ELEMENT (child), duration);
   }
   container->children_control_mode = GES_CHILDREN_UPDATE;
 
@@ -285,6 +248,17 @@ _set_priority (GESTimelineElement * element, guint32 priority)
   return TRUE;
 }
 
+static guint32
+_get_layer_priority (GESTimelineElement * element)
+{
+  GESClip *clip = GES_CLIP (element);
+
+  if (clip->priv->layer == NULL)
+    return GES_TIMELINE_ELEMENT_NO_LAYER_PRIORITY;
+
+  return ges_layer_get_priority (clip->priv->layer);
+}
+
 /****************************************************
  *                                                  *
  *  GESContainer virtual methods implementation     *
@@ -645,9 +619,8 @@ static gboolean
 _edit (GESContainer * container, GList * layers,
     gint new_layer_priority, GESEditMode mode, GESEdge edge, guint64 position)
 {
-  GList *tmp;
-  gboolean ret = TRUE;
-  GESLayer *layer;
+  GESTimeline *timeline = GES_TIMELINE_ELEMENT_TIMELINE (container);
+  GESTimelineElement *element = GES_TIMELINE_ELEMENT (container);
 
   if (!G_UNLIKELY (GES_CONTAINER_CHILDREN (container))) {
     GST_WARNING_OBJECT (container, "Trying to edit, but not containing"
@@ -655,31 +628,35 @@ _edit (GESContainer * container, GList * layers,
     return FALSE;
   }
 
-  for (tmp = GES_CONTAINER_CHILDREN (container); tmp; tmp = g_list_next (tmp)) {
-    if (GES_IS_SOURCE (tmp->data) || GES_IS_TRANSITION (tmp->data)) {
-      ret &= ges_track_element_edit (tmp->data, layers, mode, edge, position);
-      break;
-    }
+  if (!timeline) {
+    GST_WARNING_OBJECT (container, "Trying to edit, but not in any"
+        "timeline.");
+    return FALSE;
   }
 
-  /* Moving to layer */
-  if (new_layer_priority == -1) {
-    GST_DEBUG_OBJECT (container, "Not moving new prio %d", new_layer_priority);
-  } else {
-    gint priority_offset;
-
-    layer = GES_CLIP (container)->priv->layer;
-    if (layer == NULL) {
-      GST_WARNING_OBJECT (container, "Not in any layer yet, not moving");
-
+  switch (mode) {
+    case GES_EDIT_MODE_RIPPLE:
+      return timeline_ripple_object (timeline, element,
+          new_layer_priority <
+          0 ? GES_TIMELINE_ELEMENT_LAYER_PRIORITY (container) :
+          new_layer_priority, layers, edge, position);
+    case GES_EDIT_MODE_TRIM:
+      return timeline_trim_object (timeline, element,
+          new_layer_priority <
+          0 ? GES_TIMELINE_ELEMENT_LAYER_PRIORITY (container) :
+          new_layer_priority, layers, edge, position);
+    case GES_EDIT_MODE_NORMAL:
+      return timeline_move_object (timeline, element,
+          new_layer_priority <
+          0 ? GES_TIMELINE_ELEMENT_LAYER_PRIORITY (container) :
+          new_layer_priority, layers, edge, position);
+    case GES_EDIT_MODE_ROLL:
+      return timeline_roll_object (timeline, element, layers, edge, position);
+    case GES_EDIT_MODE_SLIDE:
+      GST_ERROR ("Sliding not implemented.");
       return FALSE;
-    }
-    priority_offset = new_layer_priority - ges_layer_get_priority (layer);
-
-    ret &= timeline_context_to_layer (layer->timeline, priority_offset);
   }
-
-  return ret;
+  return FALSE;
 }
 
 static void
@@ -711,12 +688,17 @@ _paste (GESTimelineElement * element, GESTimelineElement * ref,
   if (self->priv->copied_layer)
     nclip->priv->copied_layer = g_object_ref (self->priv->copied_layer);
 
-  ges_clip_set_moving_from_layer (nclip, TRUE);
-  if (self->priv->copied_layer)
-    ges_layer_add_clip (self->priv->copied_layer, nclip);
-  ges_clip_set_moving_from_layer (nclip, FALSE);
-
   ges_timeline_element_set_start (GES_TIMELINE_ELEMENT (nclip), paste_position);
+  if (self->priv->copied_layer) {
+    if (!ges_layer_add_clip (self->priv->copied_layer, nclip)) {
+      GST_INFO ("%" GES_FORMAT " could not be pasted to %" GST_TIME_FORMAT,
+          GES_ARGS (element), GST_TIME_ARGS (paste_position));
+      gst_object_unref (nclip);
+
+      return NULL;
+    }
+
+  }
 
   for (tmp = self->priv->copied_track_elements; tmp; tmp = tmp->next) {
     GESTrackElement *new_trackelement, *trackelement =
@@ -800,15 +782,18 @@ ges_clip_set_property (GObject * object, guint property_id,
 }
 
 static void
-ges_clip_finalize (GObject * object)
+ges_clip_dispose (GObject * object)
 {
   GESClip *self = GES_CLIP (object);
 
   g_list_free_full (self->priv->copied_track_elements, g_object_unref);
+  self->priv->copied_track_elements = NULL;
+  g_clear_object (&self->priv->copied_layer);
 
-  G_OBJECT_CLASS (ges_clip_parent_class)->finalize (object);
+  G_OBJECT_CLASS (ges_clip_parent_class)->dispose (object);
 }
 
+
 static void
 ges_clip_class_init (GESClipClass * klass)
 {
@@ -818,7 +803,7 @@ ges_clip_class_init (GESClipClass * klass)
 
   object_class->get_property = ges_clip_get_property;
   object_class->set_property = ges_clip_set_property;
-  object_class->finalize = ges_clip_finalize;
+  object_class->dispose = ges_clip_dispose;
   klass->create_track_elements = ges_clip_create_track_elements_func;
   klass->create_track_element = NULL;
 
@@ -861,6 +846,7 @@ ges_clip_class_init (GESClipClass * klass)
   element_class->paste = _paste;
   element_class->deep_copy = _deep_copy;
   element_class->lookup_child = _lookup_child;
+  element_class->get_layer_priority = _get_layer_priority;
 
   container_class->add_child = _add_child;
   container_class->remove_child = _remove_child;
@@ -879,7 +865,6 @@ ges_clip_init (GESClip * self)
   /* FIXME, check why it was done this way _DURATION (self) = GST_SECOND; */
   self->priv->layer = NULL;
   self->priv->nb_effects = 0;
-  self->priv->flags = 0;
 }
 
 /**
@@ -939,6 +924,7 @@ ges_clip_create_track_elements (GESClip * clip, GESTrackType type)
   GList *result = NULL, *tmp, *children;
   GESClipClass *klass;
   guint max_prio, min_prio;
+  gboolean readding_effects_only = TRUE;
 
   g_return_val_if_fail (GES_IS_CLIP (clip), NULL);
 
@@ -955,18 +941,20 @@ ges_clip_create_track_elements (GESClip * clip, GESTrackType type)
   for (tmp = children; tmp; tmp = tmp->next) {
     GESTrackElement *child = GES_TRACK_ELEMENT (tmp->data);
 
-    if (!GES_IS_BASE_EFFECT (child) && !ges_track_element_get_track (child) &&
-        ges_track_element_get_track_type (child) & type) {
+    if (!ges_track_element_get_track (child)
+        && ges_track_element_get_track_type (child) & type) {
 
       GST_DEBUG_OBJECT (clip, "Removing for reusage: %" GST_PTR_FORMAT, child);
-      result = g_list_prepend (result, g_object_ref (child));
+      result = g_list_append (result, g_object_ref (child));
       ges_container_remove (GES_CONTAINER (clip), tmp->data);
+      if (!GES_IS_BASE_EFFECT (child))
+        readding_effects_only = FALSE;
     }
   }
   g_list_free_full (children, gst_object_unref);
 
-  if (!result) {
-    result = klass->create_track_elements (clip, type);
+  if (readding_effects_only) {
+    result = g_list_concat (result, klass->create_track_elements (clip, type));
   }
 
   _get_priority_range (GES_CONTAINER (clip), &min_prio, &max_prio);
@@ -1022,19 +1010,10 @@ ges_clip_set_layer (GESClip * clip, GESLayer * layer)
    * it is actually the result of a move between layer (as we know
    * that it will be added to another layer right after, and this
    * is what imports here.) */
-  if (!FLAG_IS_SET (clip, GES_CLIP_IS_MOVING))
+  if (!ELEMENT_FLAG_IS_SET (clip, GES_CLIP_IS_MOVING))
     g_object_notify_by_pspec (G_OBJECT (clip), properties[PROP_LAYER]);
 }
 
-guint32
-ges_clip_get_layer_priority (GESClip * clip)
-{
-  if (clip->priv->layer == NULL)
-    return -1;
-
-  return ges_layer_get_priority (clip->priv->layer);
-}
-
 /**
  * ges_clip_set_moving_from_layer:
  * @clip: a #GESClip
@@ -1051,9 +1030,9 @@ ges_clip_set_moving_from_layer (GESClip * clip, gboolean is_moving)
   g_return_if_fail (GES_IS_CLIP (clip));
 
   if (is_moving)
-    SET_FLAG (clip, GES_CLIP_IS_MOVING);
+    ELEMENT_SET_FLAG (clip, GES_CLIP_IS_MOVING);
   else
-    UNSET_FLAG (clip, GES_CLIP_IS_MOVING);
+    ELEMENT_UNSET_FLAG (clip, GES_CLIP_IS_MOVING);
 }
 
 /**
@@ -1072,7 +1051,7 @@ ges_clip_is_moving_from_layer (GESClip * clip)
 {
   g_return_val_if_fail (GES_IS_CLIP (clip), FALSE);
 
-  return FLAG_IS_SET (clip, GES_CLIP_IS_MOVING);
+  return ELEMENT_FLAG_IS_SET (clip, GES_CLIP_IS_MOVING);
 }
 
 /**
@@ -1094,6 +1073,19 @@ ges_clip_move_to_layer (GESClip * clip, GESLayer * layer)
   g_return_val_if_fail (GES_IS_CLIP (clip), FALSE);
   g_return_val_if_fail (GES_IS_LAYER (layer), FALSE);
 
+  ELEMENT_SET_FLAG (clip, GES_CLIP_IS_MOVING);
+  if (layer->timeline
+      && !timeline_tree_can_move_element (timeline_get_tree (layer->timeline),
+          GES_TIMELINE_ELEMENT (clip),
+          ges_layer_get_priority (layer),
+          GES_TIMELINE_ELEMENT_START (clip),
+          GES_TIMELINE_ELEMENT_DURATION (clip), NULL)) {
+    GST_INFO_OBJECT (layer, "Clip %" GES_FORMAT " can't move to layer %d",
+        GES_ARGS (clip), ges_layer_get_priority (layer));
+    ELEMENT_UNSET_FLAG (clip, GES_CLIP_IS_MOVING);
+    return FALSE;
+  }
+
   current_layer = clip->priv->layer;
 
   if (current_layer == NULL) {
@@ -1105,17 +1097,17 @@ ges_clip_move_to_layer (GESClip * clip, GESLayer * layer)
   GST_DEBUG_OBJECT (clip, "moving to layer %p, priority: %d", layer,
       ges_layer_get_priority (layer));
 
-  SET_FLAG (clip, GES_CLIP_IS_MOVING);
   gst_object_ref (clip);
   ret = ges_layer_remove_clip (current_layer, clip);
 
   if (!ret) {
+    ELEMENT_UNSET_FLAG (clip, GES_CLIP_IS_MOVING);
     gst_object_unref (clip);
     return FALSE;
   }
 
   ret = ges_layer_add_clip (layer, clip);
-  UNSET_FLAG (clip, GES_CLIP_IS_MOVING);
+  ELEMENT_UNSET_FLAG (clip, GES_CLIP_IS_MOVING);
 
   gst_object_unref (clip);
   g_object_notify_by_pspec (G_OBJECT (clip), properties[PROP_LAYER]);
@@ -1392,6 +1384,9 @@ ges_clip_split (GESClip * clip, guint64 position)
       inpoint + old_duration * media_duration_factor);
   _set_duration0 (GES_TIMELINE_ELEMENT (new_object), new_duration);
 
+  _DURATION (clip) = old_duration;
+  g_object_notify (G_OBJECT (clip), "duration");
+
   /* We do not want the timeline to create again TrackElement-s */
   ges_clip_set_moving_from_layer (new_object, TRUE);
   ges_layer_add_clip (clip->priv->layer, new_object);
@@ -1424,16 +1419,10 @@ ges_clip_split (GESClip * clip, guint64 position)
         position - start + inpoint);
   }
 
-  SET_FLAG (clip, GES_CLIP_IS_SPLITTING);
+  ELEMENT_SET_FLAG (clip, GES_TIMELINE_ELEMENT_SET_SIMPLE);
+  _DURATION (clip) = duration;
   _set_duration0 (GES_TIMELINE_ELEMENT (clip), old_duration);
-  UNSET_FLAG (clip, GES_CLIP_IS_SPLITTING);
-
-  if (GES_TIMELINE_ELEMENT_TIMELINE (clip)) {
-    for (tmp = GES_CONTAINER_CHILDREN (new_object); tmp; tmp = tmp->next) {
-      timeline_create_transitions (GES_TIMELINE_ELEMENT_TIMELINE (tmp->data),
-          tmp->data);
-    }
-  }
+  ELEMENT_UNSET_FLAG (clip, GES_TIMELINE_ELEMENT_SET_SIMPLE);
 
   return new_object;
 }
@@ -1472,134 +1461,40 @@ ges_clip_get_supported_formats (GESClip * clip)
 gboolean
 _ripple (GESTimelineElement * element, GstClockTime start)
 {
-  gboolean ret = TRUE;
-  GESTimeline *timeline;
-  GESClip *clip = GES_CLIP (element);
-
-  timeline = ges_layer_get_timeline (clip->priv->layer);
-
-  if (timeline == NULL) {
-    GST_DEBUG ("Not in a timeline yet");
-    return FALSE;
-  }
-
-  if (start > _END (element))
-    start = _END (element);
-
-  if (GES_CONTAINER_CHILDREN (element)) {
-    GESTrackElement *track_element =
-        GES_TRACK_ELEMENT (GES_CONTAINER_CHILDREN (element)->data);
-
-    ret = timeline_ripple_object (timeline, track_element, NULL, GES_EDGE_NONE,
-        start);
-  }
-
-  return ret;
+  return ges_container_edit (GES_CONTAINER (element), NULL,
+      ges_timeline_element_get_layer_priority (element),
+      GES_EDIT_MODE_RIPPLE, GES_EDGE_NONE, start);
 }
 
 static gboolean
 _ripple_end (GESTimelineElement * element, GstClockTime end)
 {
-  gboolean ret = TRUE;
-  GESTimeline *timeline;
-  GESClip *clip = GES_CLIP (element);
-
-  timeline = ges_layer_get_timeline (clip->priv->layer);
-
-  if (timeline == NULL) {
-    GST_DEBUG ("Not in a timeline yet");
-    return FALSE;
-  }
-
-  if (GES_CONTAINER_CHILDREN (element)) {
-    GESTrackElement *track_element =
-        GES_TRACK_ELEMENT (GES_CONTAINER_CHILDREN (element)->data);
-
-    ret = timeline_ripple_object (timeline, track_element, NULL, GES_EDGE_END,
-        end);
-  }
-
-  return ret;
+  return ges_container_edit (GES_CONTAINER (element), NULL,
+      ges_timeline_element_get_layer_priority (element),
+      GES_EDIT_MODE_RIPPLE, GES_EDGE_END, end);
 }
 
 gboolean
 _roll_start (GESTimelineElement * element, GstClockTime start)
 {
-  gboolean ret = TRUE;
-  GESTimeline *timeline;
-
-  GESClip *clip = GES_CLIP (element);
-
-  timeline = ges_layer_get_timeline (clip->priv->layer);
-
-  if (timeline == NULL) {
-    GST_DEBUG ("Not in a timeline yet");
-    return FALSE;
-  }
-
-  if (GES_CONTAINER_CHILDREN (element)) {
-    GESTrackElement *track_element =
-        GES_TRACK_ELEMENT (GES_CONTAINER_CHILDREN (element)->data);
-
-    ret = timeline_roll_object (timeline, track_element, NULL, GES_EDGE_START,
-        start);
-  }
-
-  return ret;
+  return ges_container_edit (GES_CONTAINER (element), NULL,
+      ges_timeline_element_get_layer_priority (element),
+      GES_EDIT_MODE_ROLL, GES_EDGE_START, start);
 }
 
 gboolean
 _roll_end (GESTimelineElement * element, GstClockTime end)
 {
-  gboolean ret = TRUE;
-  GESTimeline *timeline;
-
-  GESClip *clip = GES_CLIP (element);
-
-  timeline = ges_layer_get_timeline (clip->priv->layer);
-  if (timeline == NULL) {
-    GST_DEBUG ("Not in a timeline yet");
-    return FALSE;
-  }
-
-
-  if (GES_CONTAINER_CHILDREN (element)) {
-    GESTrackElement *track_element =
-        GES_TRACK_ELEMENT (GES_CONTAINER_CHILDREN (element)->data);
-
-    ret = timeline_roll_object (timeline, track_element,
-        NULL, GES_EDGE_END, end);
-  }
-
-  return ret;
+  return ges_container_edit (GES_CONTAINER (element), NULL,
+      ges_timeline_element_get_layer_priority (element),
+      GES_EDIT_MODE_ROLL, GES_EDGE_END, end);
 }
 
 gboolean
 _trim (GESTimelineElement * element, GstClockTime start)
 {
-  gboolean ret = TRUE;
-  GESTimeline *timeline;
-
-  GESClip *clip = GES_CLIP (element);
-
-  timeline = ges_layer_get_timeline (clip->priv->layer);
-
-  if (timeline == NULL) {
-    GST_DEBUG ("Not in a timeline yet");
-    return FALSE;
-  }
-
-  if (GES_CONTAINER_CHILDREN (element)) {
-    GESTrackElement *track_element =
-        GES_TRACK_ELEMENT (GES_CONTAINER_CHILDREN (element)->data);
-
-    GST_DEBUG_OBJECT (element, "Trimming child: %" GST_PTR_FORMAT,
-        track_element);
-    ret = timeline_trim_object (timeline, track_element, NULL, GES_EDGE_START,
-        start);
-  }
-
-  return ret;
+  return ges_container_edit (GES_CONTAINER (element), NULL, -1,
+      GES_EDIT_MODE_TRIM, GES_EDGE_START, start);
 }
 
 /**
