@@ -353,6 +353,12 @@ ges_missing_uri_default (GESProject * self, GError * error,
   return NULL;
 }
 
+gchar *
+ges_uri_asset_try_update_id (GError * error, GESAsset * wrong_asset)
+{
+  return ges_missing_uri_default (NULL, error, wrong_asset);
+}
+
 static void
 ges_uri_assets_validate_uri (const gchar * nid)
 {
@@ -522,7 +528,7 @@ ges_project_class_init (GESProjectClass * klass)
   /**
    * GESProject::error-loading-asset:
    * @project: the #GESProject on which a problem happend when creted a #GESAsset
-   * @error: The #GError defining the error that accured, might be %NULL
+   * @error: The #GError defining the error that occured, might be %NULL
    * @id: The @id of the asset that failed loading
    * @extractable_type: The @extractable_type of the asset that
    * failed loading
