@@ -96,6 +96,8 @@ struct _GESTimelineElementPrivate
   GHashTable *children_props;
 
   GESTimelineElement *copied_from;
+
+  GESTimelineElementFlags flags;
 };
 
 typedef struct
@@ -692,6 +694,9 @@ ges_timeline_element_set_start (GESTimelineElement * self, GstClockTime start)
 
   g_return_val_if_fail (GES_IS_TIMELINE_ELEMENT (self), FALSE);
 
+  if (self->start == start)
+    return TRUE;
+
   klass = GES_TIMELINE_ELEMENT_GET_CLASS (self);
 
   GST_DEBUG_OBJECT (self, "current start: %" GST_TIME_FORMAT
@@ -1851,6 +1856,26 @@ ges_timeline_element_paste (GESTimelineElement * self,
   return g_object_ref (res);
 }
 
+/**
+ * ges_timeline_element_get_layer_priority:
+ * @self: A #GESTimelineElement
+ *
+ * Returns: The priority of the first layer the element is in (note that only
+ * groups can span over several layers). %GES_TIMELINE_ELEMENT_NO_LAYER_PRIORITY
+ * means that the element is not in a layer.
+ */
+guint32
+ges_timeline_element_get_layer_priority (GESTimelineElement * self)
+{
+  g_return_val_if_fail (GES_IS_TIMELINE_ELEMENT (self),
+      GES_TIMELINE_ELEMENT_NO_LAYER_PRIORITY);
+
+  if (!GES_TIMELINE_ELEMENT_GET_CLASS (self)->get_layer_priority)
+    return self->priority;
+
+  return GES_TIMELINE_ELEMENT_GET_CLASS (self)->get_layer_priority (self);
+}
+
 /* Internal */
 gdouble
 ges_timeline_element_get_media_duration_factor (GESTimelineElement * self)
@@ -1903,3 +1928,17 @@ ges_timeline_element_get_copied_from (GESTimelineElement * self)
   self->priv->copied_from = NULL;
   return copied_from;
 }
+
+GESTimelineElementFlags
+ges_timeline_element_flags (GESTimelineElement * self)
+{
+  return self->priv->flags;
+}
+
+void
+ges_timeline_element_set_flags (GESTimelineElement * self,
+    GESTimelineElementFlags flags)
+{
+  self->priv->flags = flags;
+
+}
