@@ -122,6 +122,15 @@ strv_find_str (const gchar ** strv, const char *str)
   return FALSE;
 }
 
+static guint32
+_get_layer_priority (GESTimelineElement * element)
+{
+  if (!element->parent)
+    return GES_TIMELINE_ELEMENT_NO_LAYER_PRIORITY;
+
+  return ges_timeline_element_get_layer_priority (element->parent);
+}
+
 static void
 ges_track_element_get_property (GObject * object, guint property_id,
     GValue * value, GParamSpec * pspec)
@@ -310,6 +319,7 @@ ges_track_element_class_init (GESTrackElementClass * klass)
   element_class->set_priority = _set_priority;
   element_class->get_track_types = _get_track_types;
   element_class->deep_copy = ges_track_element_copy_properties;
+  element_class->get_layer_priority = _get_layer_priority;
 
   klass->create_gnl_object = ges_track_element_create_gnl_object_func;
   klass->list_children_properties = default_list_children_properties;
@@ -828,15 +838,6 @@ ges_track_element_get_all_control_bindings (GESTrackElement * trackelement)
   return priv->bindings_hashtable;
 }
 
-guint32
-_ges_track_element_get_layer_priority (GESTrackElement * element)
-{
-  if (_PRIORITY (element) < LAYER_HEIGHT + MIN_NLE_PRIO)
-    return 0;
-
-  return (_PRIORITY (element) - MIN_NLE_PRIO) / LAYER_HEIGHT;
-}
-
 /**
  * ges_track_element_get_track:
  * @object: a #GESTrackElement
@@ -1363,16 +1364,21 @@ ges_track_element_edit (GESTrackElement * object,
 
   switch (mode) {
     case GES_EDIT_MODE_NORMAL:
-      return timeline_move_object (timeline, object, layers, edge, position);
+      return timeline_move_object (timeline, GES_TIMELINE_ELEMENT (object), -1,
+          layers, edge, position);
       break;
     case GES_EDIT_MODE_TRIM:
-      return timeline_trim_object (timeline, object, layers, edge, position);
+      return timeline_trim_object (timeline, GES_TIMELINE_ELEMENT (object), -1,
+          layers, edge, position);
       break;
     case GES_EDIT_MODE_RIPPLE:
-      return timeline_ripple_object (timeline, object, layers, edge, position);
+      return timeline_ripple_object (timeline, GES_TIMELINE_ELEMENT (object),
+          GES_TIMELINE_ELEMENT_PRIORITY (object) / LAYER_HEIGHT,
+          layers, edge, position);
       break;
     case GES_EDIT_MODE_ROLL:
-      return timeline_roll_object (timeline, object, layers, edge, position);
+      return timeline_roll_object (timeline, GES_TIMELINE_ELEMENT (object),
+          layers, edge, position);
       break;
     case GES_EDIT_MODE_SLIDE:
       return timeline_slide_object (timeline, object, layers, edge, position);
