@@ -27,6 +27,9 @@
  *
  * Contains the compatible TrackElement(s).
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "ges-internal.h"
 #include "ges-track.h"
@@ -35,8 +38,6 @@
 #include "ges-video-track.h"
 #include "ges-audio-track.h"
 
-G_DEFINE_TYPE_WITH_CODE (GESTrack, ges_track, GST_TYPE_BIN,
-    G_IMPLEMENT_INTERFACE (GES_TYPE_META_CONTAINER, NULL));
 #define CHECK_THREAD(track) g_assert(track->priv->valid_thread == g_thread_self())
 
 static GstStaticPadTemplate ges_track_src_pad_template =
@@ -104,6 +105,11 @@ static guint ges_track_signals[LAST_SIGNAL] = { 0 };
 
 static GParamSpec *properties[ARG_LAST];
 
+G_DEFINE_TYPE_WITH_CODE (GESTrack, ges_track, GST_TYPE_BIN,
+    G_ADD_PRIVATE (GESTrack)
+    G_IMPLEMENT_INTERFACE (GES_TYPE_META_CONTAINER, NULL));
+
+
 static void composition_duration_cb (GstElement * composition, GParamSpec * arg
     G_GNUC_UNUSED, GESTrack * obj);
 
@@ -565,8 +571,6 @@ ges_track_class_init (GESTrackClass * klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GstElementClass *gstelement_class = (GstElementClass *) klass;
 
-  g_type_class_add_private (klass, sizeof (GESTrackPrivate));
-
   gstelement_class->change_state = GST_DEBUG_FUNCPTR (ges_track_change_state);
 
   object_class->get_property = ges_track_get_property;
@@ -685,8 +689,7 @@ ges_track_class_init (GESTrackClass * klass)
 static void
 ges_track_init (GESTrack * self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-      GES_TYPE_TRACK, GESTrackPrivate);
+  self->priv = ges_track_get_instance_private (self);
   self->priv->valid_thread = g_thread_self ();
 
   self->priv->composition = gst_element_factory_make ("nlecomposition", NULL);
@@ -861,6 +864,11 @@ ges_track_update_restriction_caps (GESTrack * self, const GstCaps * caps)
   g_return_if_fail (GES_IS_TRACK (self));
   CHECK_THREAD (self);
 
+  if (!self->priv->restriction_caps) {
+    ges_track_set_restriction_caps (self, caps);
+    return;
+  }
+
   new_restriction_caps = gst_caps_copy (self->priv->restriction_caps);
   for (i = 0; i < gst_caps_get_size (caps); i++) {
     GstStructure *new = gst_caps_get_structure (caps, i);
@@ -875,6 +883,7 @@ ges_track_update_restriction_caps (GESTrack * self, const GstCaps * caps)
   }
 
   ges_track_set_restriction_caps (self, new_restriction_caps);
+  gst_caps_unref (new_restriction_caps);
 }
 
 /**
