@@ -34,8 +34,8 @@
 
 #define parent_class ges_xml_formatter_parent_class
 #define API_VERSION 0
-#define MINOR_VERSION 4
-#define VERSION 0.4
+#define MINOR_VERSION 5
+#define VERSION 0.5
 
 #define COLLECT_STR_OPT (G_MARKUP_COLLECT_STRING | G_MARKUP_COLLECT_OPTIONAL)
 
@@ -124,7 +124,7 @@ _parse_project (GMarkupParseContext * context, const gchar * element_name,
   if (g_strcmp0 (element_name, "project")) {
     g_set_error (error, G_MARKUP_ERROR,
         G_MARKUP_ERROR_INVALID_CONTENT,
-        "element '%s', Missing project element'", element_name);
+        "Found element '%s', Missing '<project>' element'", element_name);
   } else {
     priv->project_opened = TRUE;
     if (!g_markup_collect_attributes (element_name, attribute_names,
@@ -736,18 +736,18 @@ _parse_group (GMarkupParseContext * context, const gchar * element_name,
     const gchar ** attribute_names, const gchar ** attribute_values,
     GESXmlFormatter * self, GError ** error)
 {
-  const gchar *id, *properties;
+  const gchar *id, *properties, *metadatas = NULL;
 
   if (!g_markup_collect_attributes (element_name, attribute_names,
           attribute_values, error,
           G_MARKUP_COLLECT_STRING, "id", &id,
           G_MARKUP_COLLECT_STRING, "properties", &properties,
-          G_MARKUP_COLLECT_INVALID)) {
+          COLLECT_STR_OPT, "metadatas", &metadatas, G_MARKUP_COLLECT_INVALID)) {
     return;
   }
 
   ges_base_xml_formatter_add_group (GES_BASE_XML_FORMATTER (self), id,
-      properties);
+      properties, metadatas);
 }
 
 static inline void
@@ -841,7 +841,7 @@ static void
 _error_parsing (GMarkupParseContext * context, GError * error,
     gpointer user_data)
 {
-  GST_WARNING ("Error accured when parsing %s", error->message);
+  GST_WARNING ("Error occurred when parsing %s", error->message);
 }
 
 /***********************************************
@@ -1218,15 +1218,16 @@ _save_layers (GESXmlFormatter * self, GString * str, GESTimeline * timeline)
           "supported-formats", "rate", "in-point", "start", "duration",
           "max-duration", "priority", "vtype", "uri", NULL);
       extractable_id = ges_extractable_get_id (GES_EXTRACTABLE (clip));
+      metas = ges_meta_container_metas_to_string (GES_META_CONTAINER (clip));
       append_escaped (str,
           g_markup_printf_escaped ("        <clip id='%i' asset-id='%s'"
               " type-name='%s' layer-priority='%i' track-types='%i' start='%"
               G_GUINT64_FORMAT "' duration='%" G_GUINT64_FORMAT "' inpoint='%"
-              G_GUINT64_FORMAT "' rate='%d' properties='%s' ",
+              G_GUINT64_FORMAT "' rate='%d' properties='%s' metadatas='%s'",
               priv->nbelements, extractable_id,
               g_type_name (G_OBJECT_TYPE (clip)), priority,
               ges_clip_get_supported_formats (clip), _START (clip),
-              _DURATION (clip), _INPOINT (clip), 0, properties));
+              _DURATION (clip), _INPOINT (clip), 0, properties, metas));
 
       if (GES_IS_TRANSITION_CLIP (clip)) {
         _save_children_properties (str, GES_TIMELINE_ELEMENT (clip));
@@ -1295,7 +1296,7 @@ _save_group (GESXmlFormatter * self, GString * str, GList ** seen_groups,
 {
   GList *tmp;
   gboolean serialize;
-  gchar *properties;
+  gchar *properties, *metadatas;
 
   g_object_get (group, "serialize", &serialize, NULL);
   if (!serialize) {
@@ -1320,9 +1321,15 @@ _save_group (GESXmlFormatter * self, GString * str, GList ** seen_groups,
   }
 
   properties = _serialize_properties (G_OBJECT (group), NULL);
-  g_string_append_printf (str, "        <group id='%d' properties='%s'>\n",
-      self->priv->nbelements, properties);
+
+  metadatas = ges_meta_container_metas_to_string (GES_META_CONTAINER (group));
+  self->priv->min_version = MAX (self->priv->min_version, 5);
+
+  g_string_append_printf (str,
+      "        <group id='%d' properties='%s' metadatas='%s'>\n",
+      self->priv->nbelements, properties, metadatas);
   g_free (properties);
+  g_free (metadatas);
   g_hash_table_insert (self->priv->element_id, group,
       GINT_TO_POINTER (self->priv->nbelements));
   self->priv->nbelements++;
