@@ -25,19 +25,21 @@
 #define DEEP_CHECK(element, start, inpoint, duration)                          \
 {                                                                              \
   GList *track_elements, *tmp;                                                 \
-                                                                               \
-  assert_equals_uint64 (_START (element), start);                              \
-  assert_equals_uint64 (_INPOINT (element), inpoint);                          \
-  assert_equals_uint64 (_DURATION (element), duration);                        \
+  CHECK_OBJECT_PROPS (element, start, inpoint, duration)                      \
                                                                                \
   track_elements = GES_CONTAINER_CHILDREN (element);                           \
   for (tmp = track_elements; tmp; tmp = tmp->next) {                           \
-    assert_equals_uint64 (_START (tmp->data), start);                          \
-    assert_equals_uint64 (_INPOINT (tmp->data), inpoint);                      \
-    assert_equals_uint64 (_DURATION (tmp->data), duration);                    \
+    CHECK_OBJECT_PROPS (tmp->data, start, inpoint, duration)                      \
   }                                                                            \
 }
 
+#define CHECK_CLIP(element, start, inpoint, duration, layer_prio) \
+{ \
+  DEEP_CHECK(element, start, inpoint, duration);\
+  check_layer (element, layer_prio); \
+}\
+
+
 GST_START_TEST (test_basic_timeline_edition)
 {
   GESAsset *asset;
@@ -288,7 +290,7 @@ GST_START_TEST (test_snapping)
   fail_unless (ges_track_element_get_track (trackelement) == track);
   assert_equals_uint64 (_DURATION (trackelement), 37);
 
-  ASSERT_OBJECT_REFCOUNT (trackelement, "track + timeline + clip", 4);
+  ASSERT_OBJECT_REFCOUNT (trackelement, "track + timeline + clip", 3);
   ASSERT_OBJECT_REFCOUNT (clip, "layer + timeline", 2);
 
   fail_unless (ges_layer_add_clip (layer, GES_CLIP (clip1)));
@@ -299,7 +301,7 @@ GST_START_TEST (test_snapping)
   assert_equals_uint64 (_DURATION (trackelement1), 15);
 
   /* Same ref logic */
-  ASSERT_OBJECT_REFCOUNT (trackelement1, "First trackelement", 4);
+  ASSERT_OBJECT_REFCOUNT (trackelement1, "First trackelement", 3);
   ASSERT_OBJECT_REFCOUNT (clip1, "First clip", 2);
 
   fail_unless (ges_layer_add_clip (layer, GES_CLIP (clip2)));
@@ -310,7 +312,7 @@ GST_START_TEST (test_snapping)
   assert_equals_uint64 (_DURATION (trackelement2), 60);
 
   /* Same ref logic */
-  ASSERT_OBJECT_REFCOUNT (trackelement2, "First trackelement", 4);
+  ASSERT_OBJECT_REFCOUNT (trackelement2, "First trackelement", 3);
   ASSERT_OBJECT_REFCOUNT (clip2, "First clip", 2);
 
   /* Snaping to edge, so no move */
@@ -322,8 +324,7 @@ GST_START_TEST (test_snapping)
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
 
   /* Snaping to edge, so no move */
-  fail_if (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM,
-          GES_EDGE_END, 27));
+  ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM, GES_EDGE_END, 27);
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
   CHECK_OBJECT_PROPS (trackelement1, 20, 0, 5);
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
@@ -338,142 +339,78 @@ GST_START_TEST (test_snapping)
    */
   g_object_set (timeline, "snapping-distance", (guint64) 0, NULL);
   ges_timeline_element_set_duration (GES_TIMELINE_ELEMENT (clip1), 10);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 20, 0, 10);
-  CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
+  DEEP_CHECK (clip, 25, 0, 37);
+  DEEP_CHECK (clip1, 20, 0, 10);
+  DEEP_CHECK (clip2, 62, 0, 60);
 
-  /**
-   * New timeline(the "layers" are just to help reading diagram, nothing else):
-   * ------------
-   *                    0----------
-   *                    |   clip    |
-   *                    25---------62
-   * inpoints   0----------------------- 10--------
-   *            |       clip1            ||  clip2   |
-   * time      20---------------------- 72 --------122
-   */
-  /* Rolling involves only neighbour that are currently snapping */
-  fail_unless (ges_timeline_element_roll_end (GES_TIMELINE_ELEMENT (clip1),
-          62));
-  fail_unless (ges_timeline_element_roll_end (GES_TIMELINE_ELEMENT (clip1),
+  /* clip and clip1 would fully overlap ... forbiden */
+  fail_if (ges_timeline_element_roll_end (GES_TIMELINE_ELEMENT (clip1), 62));
+  DEEP_CHECK (clip, 25, 0, 37);
+  DEEP_CHECK (clip1, 20, 0, 10);
+  DEEP_CHECK (clip2, 62, 0, 60);
+  fail_if (ges_timeline_element_roll_end (GES_TIMELINE_ELEMENT (clip1),
           72) == TRUE);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 20, 0, 52);
-  CHECK_OBJECT_PROPS (trackelement2, 72, 10, 50);
+  DEEP_CHECK (clip, 25, 0, 37);
+  DEEP_CHECK (clip1, 20, 0, 10);
+  DEEP_CHECK (clip2, 62, 0, 60);
 
   /**
-   *                    0----------
-   *                    |   clip    |
-   *                    25---------62
-   * inpoints           5--------------- 10--------
-   *                    |     clip1      ||  clip2   |
-   * time               25------------- 72 --------122
+   *                        30-------+0-------------+
+   * inpoints   0-----------5  clip  ||  clip2      |
+   *            |  clip1    |------- 62 -----------122
+   * time      20----------30
    */
   g_object_set (timeline, "snapping-distance", (guint64) 4, NULL);
-  fail_unless (ges_timeline_element_trim (GES_TIMELINE_ELEMENT (clip1),
+  fail_unless (ges_timeline_element_trim (GES_TIMELINE_ELEMENT (clip),
           28) == TRUE);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 25, 5, 47);
-  CHECK_OBJECT_PROPS (trackelement2, 72, 10, 50);
+  DEEP_CHECK (clip, 30, 5, 32);
+  DEEP_CHECK (clip1, 20, 0, 10);
+  DEEP_CHECK (clip2, 62, 0, 60);
 
   /**
-   *                    0----------
-   *                    |   clip    |
-   *                    25---------62
-   * inpoints           5---------- 0---------
-   *                    |  clip1    ||  clip2   |
-   * time               25-------- 62 --------122
+   *                        30-------+0-------------+
+   * inpoints   0-----------5  clip  ||  clip2      |
+   *            |  clip1    |------- 62 -----------122
+   * time      20----------30
    */
+  fail_unless (ges_timeline_element_set_inpoint (GES_TIMELINE_ELEMENT (clip2),
+          5));
   fail_unless (ges_timeline_element_roll_start (GES_TIMELINE_ELEMENT (clip2),
-          59) == TRUE);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 25, 5, 37);
-  CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
+          60));
+  DEEP_CHECK (clip, 30, 5, 32);
+  DEEP_CHECK (clip1, 20, 0, 10);
+  DEEP_CHECK (clip2, 62, 5, 60);
 
   /**
-   *                  0----------
-   *                  |   clip  |
-   *                  25--------62
-   * inpoints           5---------- 0---------
-   *                    |  clip1    ||  clip2   |
-   * time               26-------- 62 --------122
+   *                        30-------+0-------------+
+   * inpoints   0-----------5  clip  ||  clip2      |
+   *            |  clip1    |------- 62 -----------122
+   * time      20----------30
    */
-  ges_timeline_element_set_start (GES_TIMELINE_ELEMENT (clip1), 26);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 26, 5, 37);
-  CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
+  /* Moving clip1 to 26 would lead to snapping to 30, and clip1 and clip
+   * would fully overlap */
+  fail_if (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_NORMAL,
+          GES_EDGE_NONE, 26) == TRUE);
+  DEEP_CHECK (clip, 30, 5, 32);
+  DEEP_CHECK (clip1, 20, 0, 10);
+  DEEP_CHECK (clip2, 62, 5, 60);
 
    /**
-   * inpoints           0----------5--------------
-   *                    |   clip    ||  clip1    |
-   * time               25----------62----------99
-   *                                            0-----------
-   *                                            |  clip2   |
-   *                                            98--------168
-   * Check that clip1 snaps with the end of clip */
-  fail_unless (ges_timeline_element_ripple (GES_TIMELINE_ELEMENT (clip1),
-          58) == TRUE);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 62, 5, 37);
-  CHECK_OBJECT_PROPS (trackelement2, 98, 0, 60);
-
-  /**
-   * inpoints     0----------- 5------------   0-----------
-   *              |   clip    ||  clip1    |   |  clip2    |
-   * time         25----------62----------99  110--------170
-   */
-  ges_timeline_element_set_start (GES_TIMELINE_ELEMENT (clip2), 110);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 62, 5, 37);
-  CHECK_OBJECT_PROPS (trackelement2, 110, 0, 60);
-
-  /**
-   * inpoints     0----------5    5 --------- 0----------
-   *              |   clip    |    |  clip1    ||  clip2    |
-   * time         25---------62   73---------110--------170
-   */
+   *                        30-------+0-------------+
+   * inpoints               5  clip  ||  clip2      |-------------+
+   *                        +------- 62 -----------122  clip1     |
+   * time                                           +------------132 
+   * Check that clip1 snaps with the end of clip2 */
   fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_NORMAL,
-          GES_EDGE_NONE, 72) == TRUE);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 73, 5, 37);
-  CHECK_OBJECT_PROPS (trackelement2, 110, 0, 60);
-
-  /**
-   * inpoints     0----------5----------     0----------
-   *              |   clip    ||  clip1    |   |  clip2    |
-   * time         25---------62-------- 99  110--------170
-   */
-  fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_NORMAL,
-          GES_EDGE_NONE, 58) == TRUE);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 62, 5, 37);
-  CHECK_OBJECT_PROPS (trackelement2, 110, 0, 60);
-
-
-  /**
-   * inpoints     0----------5---------- 0----------
-   *              |   clip    ||  clip1   ||  clip2    |
-   * time         25---------62--------110--------170
-   */
-  g_object_set (clip1, "duration", (guint64) 46, NULL);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 62, 5, 48);
-  CHECK_OBJECT_PROPS (trackelement2, 110, 0, 60);
-
-  /**
-   * inpoints     5----------- 0--------- 0----------
-   *              |   clip1    ||  clip2   ||  clip     |
-   * time         62---------110--------170--------207
-   */
-  g_object_set (clip, "start", (guint64) 168, NULL);
-  CHECK_OBJECT_PROPS (trackelement, 170, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 62, 5, 48);
-  CHECK_OBJECT_PROPS (trackelement2, 110, 0, 60);
+          GES_EDGE_NONE, 125) == TRUE);
+  DEEP_CHECK (clip, 30, 5, 32);
+  DEEP_CHECK (clip1, 122, 0, 10);
+  DEEP_CHECK (clip2, 62, 5, 60);
 
   /* Check we didn't lose/screwed any references */
-  ASSERT_OBJECT_REFCOUNT (trackelement, "First trackelement", 4);
-  ASSERT_OBJECT_REFCOUNT (trackelement1, "Second trackelement", 4);
-  ASSERT_OBJECT_REFCOUNT (trackelement2, "Third trackelement", 4);
+  ASSERT_OBJECT_REFCOUNT (trackelement, "First trackelement", 3);
+  ASSERT_OBJECT_REFCOUNT (trackelement1, "Second trackelement", 3);
+  ASSERT_OBJECT_REFCOUNT (trackelement2, "Third trackelement", 3);
   ASSERT_OBJECT_REFCOUNT (clip, "First clip", 2);
   ASSERT_OBJECT_REFCOUNT (clip1, "Second clip", 2);
   ASSERT_OBJECT_REFCOUNT (clip2, "Third clip", 2);
@@ -736,9 +673,7 @@ GST_START_TEST (test_timeline_edition_mode)
   CHECK_OBJECT_PROPS (trackelement, 32, 5, 3);
   CHECK_OBJECT_PROPS (trackelement1, 20, 0, 10);
   CHECK_OBJECT_PROPS (trackelement2, 35, 0, 60);
-  layer = ges_clip_get_layer (GES_CLIP (clip));
-  assert_equals_int (ges_layer_get_priority (layer), 2);
-  gst_object_unref (layer);
+  assert_equals_int (GES_TIMELINE_ELEMENT_LAYER_PRIORITY (clip), 2);
 
   /* Roll end clip to 50
    * New timeline:
@@ -782,6 +717,15 @@ GST_START_TEST (test_timeline_edition_mode)
   assert_equals_int (ges_layer_get_priority (layer), 2);
   gst_object_unref (layer);
 
+  /* Roll end clip back to 35 */
+  /* Can not move to the first layer as clip2 should move to a layer with priority < 0 */
+  fail_if (ges_container_edit (clip, NULL, 0, GES_EDIT_MODE_RIPPLE,
+          GES_EDGE_END, 52));
+  CHECK_OBJECT_PROPS (trackelement, 32, 5, 3);
+  CHECK_OBJECT_PROPS (trackelement1, 20, 0, 10);
+  CHECK_OBJECT_PROPS (trackelement2, 35, 0, 60);
+  assert_equals_int (GES_TIMELINE_ELEMENT_LAYER_PRIORITY (clip), 2);
+
   /* Ripple clip end to 52
    * New timeline:
    * ------------
@@ -795,15 +739,12 @@ GST_START_TEST (test_timeline_edition_mode)
    *                       32------52
    *
    */
-  /* Can not move to the first layer as clip2 should move to a layer with priority < 0 */
-  fail_unless (ges_container_edit (clip, NULL, 0, GES_EDIT_MODE_RIPPLE,
+  fail_unless (ges_container_edit (clip, NULL, -1, GES_EDIT_MODE_RIPPLE,
           GES_EDGE_END, 52) == TRUE);
   CHECK_OBJECT_PROPS (trackelement, 32, 5, 20);
   CHECK_OBJECT_PROPS (trackelement1, 20, 0, 10);
-  CHECK_OBJECT_PROPS (trackelement2, 52, 0, 60)
-      layer = ges_clip_get_layer (GES_CLIP (clip));
-  assert_equals_int (ges_layer_get_priority (layer), 2);
-  gst_object_unref (layer);
+  CHECK_OBJECT_PROPS (trackelement2, 52, 0, 60);
+  assert_equals_int (GES_TIMELINE_ELEMENT_LAYER_PRIORITY (clip), 2);
 
 
   /* Little check that we have 4 layers in the timeline */
@@ -819,9 +760,9 @@ GST_START_TEST (test_timeline_edition_mode)
   /* We have 3 references:
    *  track  + timeline  + clip
    */
-  ASSERT_OBJECT_REFCOUNT (trackelement, "First trackelement", 4);
-  ASSERT_OBJECT_REFCOUNT (trackelement1, "Second trackelement", 4);
-  ASSERT_OBJECT_REFCOUNT (trackelement2, "Third trackelement", 4);
+  ASSERT_OBJECT_REFCOUNT (trackelement, "First trackelement", 3);
+  ASSERT_OBJECT_REFCOUNT (trackelement1, "Second trackelement", 3);
+  ASSERT_OBJECT_REFCOUNT (trackelement2, "Third trackelement", 3);
   ASSERT_OBJECT_REFCOUNT (clip, "First clip", 2);
   ASSERT_OBJECT_REFCOUNT (clip1, "Second clip", 2);
   ASSERT_OBJECT_REFCOUNT (clip2, "Third clip", 2);
@@ -906,16 +847,13 @@ GST_START_TEST (test_timeline_edition_mode)
 
   /* Snaping to edge, so no move */
   g_object_set (timeline, "snapping-distance", (guint64) 3, NULL);
-  fail_if (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM,
-          GES_EDGE_END, 27));
+  ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM, GES_EDGE_END, 27);
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
   CHECK_OBJECT_PROPS (trackelement1, 20, 0, 5);
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
 
   /* Snaping to edge, so no move */
-  fail_if (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM,
-          GES_EDGE_END, 27));
-
+  ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_TRIM, GES_EDGE_END, 27);
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
   CHECK_OBJECT_PROPS (trackelement1, 20, 0, 5);
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
@@ -941,13 +879,13 @@ GST_START_TEST (test_timeline_edition_mode)
    *                    0----------
    *                    |   clip   |
    *                    25---------62
+   * -------------------------------------------------
    * inpoints   0----------------------- 10--------
    *            |       clip1           ||  clip2  |
    * time      20---------------------- 72 --------122
    */
   /* Rolling involves only neighbours that are currently snapping */
-  fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_ROLL,
-          GES_EDGE_END, 62) == TRUE);
+  ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_ROLL, GES_EDGE_END, 62);
   fail_unless (ges_container_edit (clip1, NULL, -1, GES_EDIT_MODE_ROLL,
           GES_EDGE_END, 72) == TRUE);
   CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
@@ -970,19 +908,8 @@ GST_START_TEST (test_timeline_edition_mode)
   CHECK_OBJECT_PROPS (trackelement1, 25, 5, 47);
   CHECK_OBJECT_PROPS (trackelement2, 72, 10, 50);
 
-  /**
-   *                    0----------
-   *                    |   clip   |
-   *                    25---------62
-   * inpoints           5---------- 0---------
-   *                    |  clip1   ||  clip2  |
-   * time               25-------- 62 --------122
-   */
-  fail_unless (ges_container_edit (clip2, NULL, -1, GES_EDIT_MODE_ROLL,
-          GES_EDGE_START, 59) == TRUE);
-  CHECK_OBJECT_PROPS (trackelement, 25, 0, 37);
-  CHECK_OBJECT_PROPS (trackelement1, 25, 5, 37);
-  CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
+  fail_if (ges_container_edit (clip2, NULL, -1, GES_EDIT_MODE_ROLL,
+          GES_EDGE_START, 59));
 
   ges_deinit ();
 }
@@ -1042,132 +969,70 @@ GST_START_TEST (test_groups)
   g_list_free (clips);
 
   fail_unless (GES_IS_GROUP (group));
-  DEEP_CHECK (c, 0, 0, 10);
-  DEEP_CHECK (c1, 10, 0, 10);
-  DEEP_CHECK (c2, 20, 0, 10);
+  CHECK_CLIP (c, 0, 0, 10, 0);
+  CHECK_CLIP (c1, 10, 0, 10, 1);
+  CHECK_CLIP (c2, 20, 0, 10, 1);
   CHECK_OBJECT_PROPS (group, 0, 0, 30);
 
   c3 = ges_layer_add_asset (layer, asset, 30, 0, 20, GES_TRACK_TYPE_UNKNOWN);
   c4 = ges_layer_add_asset (layer1, asset, 40, 0, 20, GES_TRACK_TYPE_UNKNOWN);
   c5 = ges_layer_add_asset (layer2, asset, 50, 0, 20, GES_TRACK_TYPE_UNKNOWN);
 
-  DEEP_CHECK (c3, 30, 0, 20);
-  DEEP_CHECK (c4, 40, 0, 20);
-  DEEP_CHECK (c5, 50, 0, 20);
+  CHECK_CLIP (c3, 30, 0, 20, 0);
+  CHECK_CLIP (c4, 40, 0, 20, 1);
+  CHECK_CLIP (c5, 50, 0, 20, 2);
   check_layer (c, 0);
   check_layer (c1, 1);
   check_layer (c2, 1);
-  check_layer (c3, 0);
-  check_layer (c4, 1);
-  check_layer (c5, 2);
 
   fail_unless (ges_container_edit (GES_CONTAINER (c), NULL, -1,
           GES_EDIT_MODE_RIPPLE, GES_EDGE_NONE, 10) == TRUE);
 
-  DEEP_CHECK (c, 10, 0, 10);
-  DEEP_CHECK (c1, 20, 0, 10);
-  DEEP_CHECK (c2, 30, 0, 10);
-  DEEP_CHECK (c3, 40, 0, 20);
-  DEEP_CHECK (c4, 50, 0, 20);
-  DEEP_CHECK (c5, 60, 0, 20);
-  check_layer (c, 0);
-  check_layer (c1, 1);
-  check_layer (c2, 1);
-  check_layer (c3, 0);
-  check_layer (c4, 1);
-  check_layer (c5, 2);
+  CHECK_CLIP (c, 10, 0, 10, 0);
+  CHECK_CLIP (c1, 20, 0, 10, 1);
+  CHECK_CLIP (c2, 30, 0, 10, 1);
+  CHECK_CLIP (c3, 40, 0, 20, 0);
+  CHECK_CLIP (c4, 50, 0, 20, 1);
+  CHECK_CLIP (c5, 60, 0, 20, 2);
 
   fail_unless (ges_container_edit (GES_CONTAINER (c), NULL, 1,
           GES_EDIT_MODE_RIPPLE, GES_EDGE_NONE, 10) == TRUE);
-  DEEP_CHECK (c, 10, 0, 10);
-  DEEP_CHECK (c1, 20, 0, 10);
-  DEEP_CHECK (c2, 30, 0, 10);
-  DEEP_CHECK (c3, 40, 0, 20);
-  DEEP_CHECK (c4, 50, 0, 20);
-  DEEP_CHECK (c5, 60, 0, 20);
-  check_layer (c, 1);
-  check_layer (c1, 2);
-  check_layer (c2, 2);
-  check_layer (c3, 1);
-  check_layer (c4, 2);
-  check_layer (c5, 3);
+  CHECK_CLIP (c, 10, 0, 10, 1);
+  CHECK_CLIP (c1, 20, 0, 10, 2);
+  CHECK_CLIP (c2, 30, 0, 10, 2);
+  CHECK_CLIP (c3, 40, 0, 20, 1);
+  CHECK_CLIP (c4, 50, 0, 20, 2);
+  CHECK_CLIP (c5, 60, 0, 20, 3);
 
-  fail_unless (ges_container_edit (GES_CONTAINER (c1), NULL, 2,
+  fail_if (ges_container_edit (GES_CONTAINER (c1), NULL, 2,
           GES_EDIT_MODE_RIPPLE, GES_EDGE_END, 40) == TRUE);
-  DEEP_CHECK (c, 10, 0, 10);
-  DEEP_CHECK (c1, 20, 0, 20);
-  DEEP_CHECK (c2, 40, 0, 10);
-  DEEP_CHECK (c3, 50, 0, 20);
-  DEEP_CHECK (c4, 60, 0, 20);
-  DEEP_CHECK (c5, 70, 0, 20);
-  check_layer (c, 1);
-  check_layer (c1, 2);
-  check_layer (c2, 2);
-  check_layer (c3, 1);
-  check_layer (c4, 2);
-  check_layer (c5, 3);
-
-  fail_unless (ges_container_edit (GES_CONTAINER (c1), NULL, 2,
+  fail_if (ges_container_edit (GES_CONTAINER (c1), NULL, 2,
           GES_EDIT_MODE_RIPPLE, GES_EDGE_END, 30) == TRUE);
-  DEEP_CHECK (c, 10, 0, 10);
-  DEEP_CHECK (c1, 20, 0, 10);
-  DEEP_CHECK (c2, 30, 0, 10);
-  DEEP_CHECK (c3, 40, 0, 20);
-  DEEP_CHECK (c4, 50, 0, 20);
-  DEEP_CHECK (c5, 60, 0, 20);
-  check_layer (c, 1);
-  check_layer (c1, 2);
-  check_layer (c2, 2);
-  check_layer (c3, 1);
-  check_layer (c4, 2);
-  check_layer (c5, 3);
-
+  CHECK_CLIP (c, 10, 0, 10, 1);
+  CHECK_CLIP (c1, 20, 0, 10, 2);
+  CHECK_CLIP (c2, 30, 0, 10, 2);
+  CHECK_CLIP (c3, 40, 0, 20, 1);
+  CHECK_CLIP (c4, 50, 0, 20, 2);
+  CHECK_CLIP (c5, 60, 0, 20, 3);
   fail_unless (ges_container_edit (GES_CONTAINER (c), NULL, 0,
           GES_EDIT_MODE_RIPPLE, GES_EDGE_NONE, 0) == TRUE);
-  DEEP_CHECK (c, 0, 0, 10);
-  DEEP_CHECK (c1, 10, 0, 10);
-  DEEP_CHECK (c2, 20, 0, 10);
-  DEEP_CHECK (c3, 30, 0, 20);
-  DEEP_CHECK (c4, 40, 0, 20);
-  DEEP_CHECK (c5, 50, 0, 20);
-  check_layer (c, 0);
-  check_layer (c1, 1);
-  check_layer (c2, 1);
-  check_layer (c3, 0);
-  check_layer (c4, 1);
-  check_layer (c5, 2);
-
-  fail_unless (ges_container_edit (GES_CONTAINER (c2), NULL, -1,
-          GES_EDIT_MODE_ROLL, GES_EDGE_END, 40) == TRUE);
-  DEEP_CHECK (c, 0, 0, 10);
-  DEEP_CHECK (c1, 10, 0, 10);
-  DEEP_CHECK (c2, 20, 0, 20);
-  DEEP_CHECK (c3, 40, 10, 10);
-  DEEP_CHECK (c4, 40, 0, 20);
-  DEEP_CHECK (c5, 50, 0, 20);
-  CHECK_OBJECT_PROPS (group, 0, 0, 40);
-  check_layer (c, 0);
-  check_layer (c1, 1);
-  check_layer (c2, 1);
-  check_layer (c3, 0);
-  check_layer (c4, 1);
-  check_layer (c5, 2);
+  CHECK_CLIP (c, 0, 0, 10, 0);
+  CHECK_CLIP (c1, 10, 0, 10, 1);
+  CHECK_CLIP (c2, 20, 0, 10, 1);
+  CHECK_CLIP (c3, 30, 0, 20, 0);
+  CHECK_CLIP (c4, 40, 0, 20, 1);
+  CHECK_CLIP (c5, 50, 0, 20, 2);
+  CHECK_OBJECT_PROPS (group, 0, 0, 30);
 
   fail_unless (ges_container_edit (GES_CONTAINER (c), NULL, 0,
           GES_EDIT_MODE_TRIM, GES_EDGE_START, 5) == TRUE);
-  CHECK_OBJECT_PROPS (c, 5, 5, 5);
-  CHECK_OBJECT_PROPS (c1, 10, 0, 10);
-  CHECK_OBJECT_PROPS (c2, 20, 0, 20);
-  CHECK_OBJECT_PROPS (c3, 40, 10, 10);
-  CHECK_OBJECT_PROPS (c4, 40, 0, 20);
-  CHECK_OBJECT_PROPS (c5, 50, 0, 20);
-  CHECK_OBJECT_PROPS (group, 5, 0, 35);
-  check_layer (c, 0);
-  check_layer (c1, 1);
-  check_layer (c2, 1);
-  check_layer (c3, 0);
-  check_layer (c4, 1);
-  check_layer (c5, 2);
+  CHECK_CLIP (c, 5, 5, 5, 0);
+  CHECK_CLIP (c1, 10, 0, 10, 1);
+  CHECK_CLIP (c2, 20, 0, 10, 1);
+  CHECK_CLIP (c3, 30, 0, 20, 0);
+  CHECK_CLIP (c4, 40, 0, 20, 1);
+  CHECK_CLIP (c5, 50, 0, 20, 2);
+  CHECK_OBJECT_PROPS (group, 5, 0, 25);
 
   gst_object_unref (timeline);
   gst_object_unref (asset);
